best_match

Function best_match 

pub fn best_match<'a>(
    constraint: &str,
    versions: &'a [String],
) -> Option<&'a str>
The highest of versions that satisfies constraint, or None if none do. Deterministic — the resolver records this exact version in the lock file.