Expr

Enum Expr 

pub enum Expr {
Show 16 variants Lit(Literal), Var(String), Block(Block), Call { callee: Box<Expr>, args: Vec<Expr>, }, Pipe { left: Box<Expr>, right: Box<Expr>, }, Try(Box<Expr>), Field { value: Box<Expr>, field: String, }, BinOp { op: BinOp, lhs: Box<Expr>, rhs: Box<Expr>, }, UnaryOp { op: UnaryOp, expr: Box<Expr>, }, If { cond: Box<Expr>, then_block: Block, else_block: Block, }, Match { scrutinee: Box<Expr>, arms: Vec<Arm>, }, RecordLit(Vec<RecordLitField>), TupleLit(Vec<Expr>), ListLit(Vec<Expr>), Constructor { name: String, args: Vec<Expr>, }, Lambda(Box<Lambda>),
}

Variants



Lit(Literal)



Var(String)



Block(Block)



Call

Fields

callee: Box<Expr>
args: Vec<Expr>


Pipe

Fields

left: Box<Expr>
right: Box<Expr>


Try(Box<Expr>)

expr? postfix.



Field

expr.field

Fields

value: Box<Expr>
field: String


BinOp

Fields

lhs: Box<Expr>
rhs: Box<Expr>


UnaryOp

Fields

expr: Box<Expr>


If

Fields

cond: Box<Expr>
then_block: Block
else_block: Block


Match

Fields

scrutinee: Box<Expr>
arms: Vec<Arm>


RecordLit(Vec<RecordLitField>)



TupleLit(Vec<Expr>)



ListLit(Vec<Expr>)



Constructor

A bare constructor name (None, Empty) or constructor call (Ok(x)). Since we cannot distinguish a constructor from a variable at parse time, the parser emits Var/Call and the type checker resolves it. This variant is kept for the canonicalizer to lift detected constructors into.

Fields

name: String
args: Vec<Expr>


Lambda(Box<Lambda>)